@@ -31,7 +31,8 @@ class GraphiteClient(object):
 
     """
     def __init__(self, prefix=None, graphite_server=None, graphite_port=2003,
-                 debug=False, group=None, system_name=None, suffix=None):
+                 debug=False, group=None, system_name=None, suffix=None,
+                 lowercase_metric_names=False):
         """ setup the connection to the graphite server and work out the
         prefix.
         This allows for very simple syntax when sending messages to the
@@ -46,18 +47,20 @@ class GraphiteClient(object):
         self.debug = debug
         self.lastmessage = None
 
+        self.lowercase_metric_names = lowercase_metric_names
+
         if system_name is None:
             system_name = os.uname()[1]
 
         if prefix is None:
             prefix = "systems.%(system_name)s" % locals()
 
-        if group:
-            prefix = prefix + "." + group
-
         if prefix:
             prefix = prefix + "."
 
+        if group:
+            prefix = prefix + "." + group
+
         # remove double dots
         if '..' in prefix:
             prefix = prefix.replace('..','.')
@@ -111,6 +114,11 @@ class GraphiteClient(object):
 
     def _send(self, message):
         """ Given a message send it to the graphite server. """
+
+        # An option to lowercase the entire message
+        if self.lowercase_metric_names:
+            message = message.lower()
+
         try:
             self.socket.sendall(message)
 
@@ -142,6 +150,9 @@ class GraphiteClient(object):
         else:
             timestamp = int(timestamp)
 
+        if type(value).__name__ in ['str','unicode']:
+            value = float(value)
+
         message = "%s%s%s %f %d\n" % (self.prefix, metric, self.suffix,
                                       value, timestamp)
 
@@ -159,6 +170,8 @@ class GraphiteClient(object):
         metric_list = []
 
         for metric, value in data.items():
+            if type(value).__name__ in ['str','unicode']:
+                value = float(value)
             tmp_message = "%s%s%s %f %d\n" % (self.prefix, metric,
                                               self.suffix, value, timestamp)
             metric_list.append(tmp_message)
@@ -166,6 +179,29 @@ class GraphiteClient(object):
         message = "".join(metric_list)
         return self._send(message)
 
+    def send_list(self, data, timestamp=None):
+        """ Format a list of set's of (metric, value) pairs, and send them all
+        to the graphite server.
+        """
+        if timestamp is None:
+            timestamp = int(time.time())
+        else:
+            timestamp = int(timestamp)
+
+        metric_list = []
+
+        for metric, value in data:
+            if type(value).__name__ in ['str','unicode']:
+                print "metric='%(metric)s'  value='%(value)s'" % locals()
+                value = float(value)
+            tmp_message = "%s%s%s %f %d\n" % (self.prefix, metric,
+                                              self.suffix, value, timestamp)
+            metric_list.append(tmp_message)
+
+        message = "".join(metric_list)
+        return self._send(message)
+
+
 
 def init(*args, **kwargs):
     """ Create the module instance of the GraphiteClient. """
@@ -197,6 +233,16 @@ def send_dict(*args, **kwargs):
     _module_instance.send_dict(*args, **kwargs)
     return _module_instance
 
+def send_list(*args, **kwargs):
+    """ Make sure that we have an instance of the GraphiteClient.
+    Then send the metrics to the graphite server.
+    User consumable method.
+    """
+    if not _module_instance:
+        raise GraphiteSendException("Must call graphitesend.init() before sending")
+    _module_instance.send_list(*args, **kwargs)
+    return _module_instance
+
 
 def reset():
     """ disconnect from the graphite server and destroy the module instance.
